@@ -1,21 +1,21 @@
 /*
  * Copyright (C) 1996-2000,2002,2013 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1999-2004,2006 Thomas Roessler <roessler@does-not-exist.org>
- * 
+ *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation; either version 2 of the License, or
  *     (at your option) any later version.
- * 
+ *
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
- * 
+ *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */ 
+ */
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -50,8 +50,8 @@ int mutt_get_tmp_attachment (BODY *a)
   rfc1524_entry *entry = NULL;
   FILE *fpin = NULL, *fpout = NULL;
   struct stat st;
-  
-  if(a->unlink)
+
+  if (a->unlink)
     return 0;
 
   tempfile = mutt_buffer_pool_get ();
@@ -59,34 +59,34 @@ int mutt_get_tmp_attachment (BODY *a)
 
   snprintf(type, sizeof(type), "%s/%s", TYPE(a), a->subtype);
   rfc1524_mailcap_lookup(a, type, entry, 0);
-  mutt_buffer_rfc1524_expand_filename (entry->nametemplate, a->filename, tempfile);
+  mutt_rfc1524_expand_filename (entry->nametemplate, a->filename, tempfile);
 
   rfc1524_free_entry(&entry);
 
-  if(stat(a->filename, &st) == -1)
+  if (stat(a->filename, &st) == -1)
   {
     mutt_buffer_pool_release (&tempfile);
     return -1;
   }
 
-  if((fpin = fopen(a->filename, "r")) &&              /* __FOPEN_CHECKED__ */
-     (fpout = safe_fopen(mutt_b2s (tempfile), "w")))
+  if ((fpin = fopen(a->filename, "r")) &&              /* __FOPEN_CHECKED__ */
+      (fpout = safe_fopen(mutt_b2s (tempfile), "w")))
   {
     mutt_copy_stream (fpin, fpout);
     mutt_str_replace (&a->filename, mutt_b2s (tempfile));
     a->unlink = 1;
 
-    if(a->stamp >= st.st_mtime)
+    if (a->stamp >= st.st_mtime)
       mutt_stamp_attachment(a);
   }
   else
     mutt_perror(fpin ? mutt_b2s (tempfile) : a->filename);
-  
-  if(fpin)  safe_fclose (&fpin);
-  if(fpout) safe_fclose (&fpout);
+
+  if (fpin)  safe_fclose (&fpin);
+  if (fpout) safe_fclose (&fpout);
 
   mutt_buffer_pool_release (&tempfile);
-  
+
   return a->unlink ? 0 : -1;
 }
 
@@ -109,11 +109,11 @@ int mutt_compose_attachment (BODY *a)
     {
       if (entry->composetypecommand)
 	mutt_buffer_strcpy (command, entry->composetypecommand);
-      else 
+      else
 	mutt_buffer_strcpy (command, entry->composecommand);
 
-      if (mutt_buffer_rfc1524_expand_filename (entry->nametemplate,
-                                               a->filename, newfile))
+      if (mutt_rfc1524_expand_filename (entry->nametemplate,
+                                        a->filename, newfile))
       {
 	dprint(1, (debugfile, "oldfile: %s\t newfile: %s\n",
                    a->filename, mutt_b2s (newfile)));
@@ -127,9 +127,8 @@ int mutt_compose_attachment (BODY *a)
       }
       else
 	mutt_buffer_strcpy (newfile, a->filename);
-      
-      if (mutt_buffer_rfc1524_expand_command (a, mutt_b2s (newfile), type,
-                                              command))
+
+      if (mutt_rfc1524_expand_command (a, mutt_b2s (newfile), type, command))
       {
 	/* For now, editing requires a file, no piping */
 	mutt_error _("Mailcap compose entry requires %%s");
@@ -141,7 +140,7 @@ int mutt_compose_attachment (BODY *a)
 	mutt_endwin (NULL);
 	if ((r = mutt_system (mutt_b2s (command))) == -1)
 	  mutt_error (_("Error running \"%s\"!"), mutt_b2s (command));
-	
+
 	if (r != -1 && entry->composetypecommand)
 	{
 	  BODY *b;
@@ -162,7 +161,8 @@ int mutt_compose_attachment (BODY *a)
 	      a->parameter = b->parameter;
 	      b->parameter = NULL;
 	    }
-	    if (b->description) {
+	    if (b->description)
+            {
 	      FREE (&a->description);
 	      a->description = b->description;
 	      b->description = NULL;
@@ -174,7 +174,7 @@ int mutt_compose_attachment (BODY *a)
 	      b->form_name = NULL;
 	    }
 
-	    /* Remove headers by copying out data to another file, then 
+	    /* Remove headers by copying out data to another file, then
 	     * copying the file back */
 	    fseeko (fp, b->offset, 0);
 	    mutt_buffer_mktemp (tempfile);
@@ -186,8 +186,8 @@ int mutt_compose_attachment (BODY *a)
 	    mutt_copy_stream (fp, tfp);
 	    safe_fclose (&fp);
 	    safe_fclose (&tfp);
-	    mutt_unlink (a->filename);  
-	    if (mutt_rename_file (mutt_b2s (tempfile), a->filename) != 0) 
+	    mutt_unlink (a->filename);
+	    if (mutt_rename_file (mutt_b2s (tempfile), a->filename) != 0)
 	    {
 	      mutt_perror _("Failure to rename file.");
 	      goto bailout;
@@ -202,7 +202,7 @@ int mutt_compose_attachment (BODY *a)
   else
   {
     mutt_message (_("No mailcap compose entry for %s, creating empty file."),
-		   type);
+                  type);
     rc = 1;
     goto bailout;
   }
@@ -211,7 +211,7 @@ int mutt_compose_attachment (BODY *a)
 
 bailout:
 
-  if(unlink_newfile)
+  if (unlink_newfile)
     unlink(mutt_b2s (newfile));
 
   mutt_buffer_pool_release (&command);
@@ -222,8 +222,8 @@ bailout:
   return rc;
 }
 
-/* 
- * Currently, this only works for send mode, as it assumes that the 
+/*
+ * Currently, this only works for send mode, as it assumes that the
  * BODY->filename actually contains the information.  I'm not sure
  * we want to deal with editing attachments we've already received,
  * so this should be ok.
@@ -247,8 +247,8 @@ int mutt_edit_attachment (BODY *a)
     {
 
       mutt_buffer_strcpy (command, entry->editcommand);
-      if (mutt_buffer_rfc1524_expand_filename (entry->nametemplate,
-                                               a->filename, newfile))
+      if (mutt_rfc1524_expand_filename (entry->nametemplate,
+                                        a->filename, newfile))
       {
 	dprint(1, (debugfile, "oldfile: %s\t newfile: %s\n",
                    a->filename, mutt_b2s (newfile)));
@@ -263,8 +263,7 @@ int mutt_edit_attachment (BODY *a)
       else
 	mutt_buffer_strcpy (newfile, a->filename);
 
-      if (mutt_buffer_rfc1524_expand_command (a, mutt_b2s (newfile), type,
-                                              command))
+      if (mutt_rfc1524_expand_command (a, mutt_b2s (newfile), type, command))
       {
 	/* For now, editing requires a file, no piping */
 	mutt_error _("Mailcap Edit entry requires %%s");
@@ -294,15 +293,15 @@ int mutt_edit_attachment (BODY *a)
   }
 
   rc = 1;
-  
-  bailout:
-  
-  if(unlink_newfile)
+
+bailout:
+
+  if (unlink_newfile)
     unlink(mutt_b2s (newfile));
 
   mutt_buffer_pool_release (&command);
   mutt_buffer_pool_release (&newfile);
-  
+
   rfc1524_free_entry (&entry);
   return rc;
 }
@@ -313,32 +312,34 @@ void mutt_check_lookup_list (BODY *b, char *type, int len)
   LIST *t = MimeLookupList;
   int i;
 
-  for (; t; t = t->next) {
+  for (; t; t = t->next)
+  {
     i = mutt_strlen (t->data) - 1;
-    if ((i > 0 && t->data[i-1] == '/' && t->data[i] == '*' && 
+    if ((i > 0 && t->data[i-1] == '/' && t->data[i] == '*' &&
 	 ascii_strncasecmp (type, t->data, i) == 0) ||
-	ascii_strcasecmp (type, t->data) == 0) {
-
-    BODY tmp = {0};
-    int n;
-    if ((n = mutt_lookup_mime_type (&tmp, b->filename)) != TYPEOTHER) {
-      snprintf (type, len, "%s/%s",
-                n == TYPEAUDIO ? "audio" :
-                n == TYPEAPPLICATION ? "application" :
-                n == TYPEIMAGE ? "image" :
-                n == TYPEMESSAGE ? "message" :
-                n == TYPEMODEL ? "model" :
-                n == TYPEMULTIPART ? "multipart" :
-                n == TYPETEXT ? "text" :
-                n == TYPEVIDEO ? "video" : "other",
-                tmp.subtype);
-      dprint(1, (debugfile, "mutt_check_lookup_list: \"%s\" -> %s\n", 
-        b->filename, type));
-    }
-    if (tmp.subtype) 
-      FREE (&tmp.subtype);
-    if (tmp.xtype) 
-      FREE (&tmp.xtype);
+	ascii_strcasecmp (type, t->data) == 0)
+    {
+      BODY tmp = {0};
+      int n;
+      if ((n = mutt_lookup_mime_type (&tmp, b->filename)) != TYPEOTHER)
+      {
+        snprintf (type, len, "%s/%s",
+                  n == TYPEAUDIO ? "audio" :
+                  n == TYPEAPPLICATION ? "application" :
+                  n == TYPEIMAGE ? "image" :
+                  n == TYPEMESSAGE ? "message" :
+                  n == TYPEMODEL ? "model" :
+                  n == TYPEMULTIPART ? "multipart" :
+                  n == TYPETEXT ? "text" :
+                  n == TYPEVIDEO ? "video" : "other",
+                  tmp.subtype);
+        dprint(1, (debugfile, "mutt_check_lookup_list: \"%s\" -> %s\n",
+                   b->filename, type));
+      }
+      if (tmp.subtype)
+        FREE (&tmp.subtype);
+      if (tmp.xtype)
+        FREE (&tmp.xtype);
     }
   }
 }
@@ -360,7 +361,7 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
   rfc1524_entry *entry = NULL;
   int rc = -1;
   int unlink_tempfile = 0;
-  
+
   is_message = mutt_is_message_type(a->type, a->subtype);
   if (WithCrypto && is_message && a->hdr && (a->hdr->security & ENCRYPT) &&
       !crypt_valid_passphrase(a->hdr->security))
@@ -371,12 +372,12 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
   command = mutt_buffer_pool_get ();
 
   use_mailcap = (flag == MUTT_MAILCAP ||
-		(flag == MUTT_REGULAR && mutt_needs_mailcap (a)));
+                 (flag == MUTT_REGULAR && mutt_needs_mailcap (a)));
   snprintf (type, sizeof (type), "%s/%s", TYPE (a), a->subtype);
-  
+
   if (use_mailcap)
   {
-    entry = rfc1524_new_entry (); 
+    entry = rfc1524_new_entry ();
     if (!rfc1524_mailcap_lookup (a, type, entry, 0))
     {
       if (flag == MUTT_REGULAR)
@@ -391,7 +392,7 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
 	goto return_error;
     }
   }
-  
+
   if (use_mailcap)
   {
     if (!entry->command)
@@ -400,7 +401,7 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
       goto return_error;
     }
     mutt_buffer_strcpy (command, entry->command);
-    
+
     if (fp)
     {
       fname = safe_strdup (a->filename);
@@ -409,8 +410,8 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
     else
       fname = a->filename;
 
-    if (mutt_buffer_rfc1524_expand_filename (entry->nametemplate, fname,
-                                             tempfile))
+    if (mutt_rfc1524_expand_filename (entry->nametemplate, fname,
+                                      tempfile))
     {
       if (fp == NULL && mutt_strcmp(mutt_b2s (tempfile), a->filename))
       {
@@ -428,7 +429,7 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
     }
     else if (fp == NULL) /* send case */
       mutt_buffer_strcpy (tempfile, a->filename);
-    
+
     if (fp)
     {
       /* recv case: we need to save the attachment to a file */
@@ -437,28 +438,28 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
 	goto return_error;
     }
 
-    use_pipe = mutt_buffer_rfc1524_expand_command (a, mutt_b2s (tempfile), type,
-                                                   command);
+    use_pipe = mutt_rfc1524_expand_command (a, mutt_b2s (tempfile), type,
+                                            command);
     use_pager = entry->copiousoutput;
   }
-  
+
   if (use_pager)
   {
     if (fp && !use_mailcap && a->filename)
     {
       /* recv case */
       mutt_buffer_strcpy (pagerfile, a->filename);
-      mutt_buffer_adv_mktemp (pagerfile);
+      mutt_adv_mktemp (pagerfile);
     }
     else
       mutt_buffer_mktemp (pagerfile);
   }
-    
+
   if (use_mailcap)
   {
     pid_t thepid = 0;
     int tempfd = -1, pagerfd = -1;
-    
+
     if (!use_pager)
       mutt_endwin (NULL);
 
@@ -471,7 +472,7 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
       }
       if (use_pipe && ((tempfd = open (mutt_b2s (tempfile), 0)) == -1))
       {
-	if(pagerfd != -1)
+	if (pagerfd != -1)
 	  close(pagerfd);
 	mutt_perror ("open");
 	goto return_error;
@@ -480,10 +481,10 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
       if ((thepid = mutt_create_filter_fd (mutt_b2s (command), NULL, NULL, NULL,
 					   use_pipe ? tempfd : -1, use_pager ? pagerfd : -1, -1)) == -1)
       {
-	if(pagerfd != -1)
+	if (pagerfd != -1)
 	  close(pagerfd);
-	
-	if(tempfd != -1)
+
+	if (tempfd != -1)
 	  close(tempfd);
 
 	mutt_error _("Cannot create filter");
@@ -577,22 +578,22 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
       }
       unset_option (OPTVIEWATTACH);
     }
-    
+
     if (a->description)
       strfcpy (descrip, a->description, sizeof (descrip));
     else if (a->filename)
       snprintf (descrip, sizeof (descrip), _("---Attachment: %s: %s"),
-	  a->filename, type);
+                a->filename, type);
     else
       snprintf (descrip, sizeof (descrip), _("---Attachment: %s"), type);
   }
-  
+
   /* We only reach this point if there have been no errors */
 
   if (use_pager)
   {
     pager_t info;
-    
+
     memset (&info, 0, sizeof (info));
     info.fp = fp;
     info.bdy = a;
@@ -607,8 +608,8 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
   else
     rc = 0;
 
-  return_error:
-  
+return_error:
+
   if (entry)
     rfc1524_free_entry (&entry);
   if (fp && (mutt_b2s (tempfile))[0])
@@ -632,7 +633,7 @@ int mutt_pipe_attachment (FILE *fp, BODY *b, const char *path, char *outfile)
   pid_t thepid;
   int out = -1;
   int rv = 0;
-  
+
   if (outfile && *outfile)
     if ((out = safe_open (outfile, O_CREAT | O_EXCL | O_WRONLY)) < 0)
     {
@@ -662,7 +663,7 @@ int mutt_pipe_attachment (FILE *fp, BODY *b, const char *path, char *outfile)
       mutt_perror _("Can't create filter");
       goto bail;
     }
-    
+
     s.fpin = fp;
     mutt_decode_attachment (b, &s);
     safe_fclose (&s.fpout);
@@ -695,16 +696,16 @@ int mutt_pipe_attachment (FILE *fp, BODY *b, const char *path, char *outfile)
       safe_fclose (&ifp);
       goto bail;
     }
-    
+
     mutt_copy_stream (ifp, ofp);
     safe_fclose (&ofp);
     safe_fclose (&ifp);
   }
 
   rv = 1;
-  
+
 bail:
-  
+
   if (outfile && *outfile)
     close (out);
 
@@ -726,7 +727,7 @@ mutt_save_attachment_open (const char *path, int flags)
     return fopen (path, "a");
   if (flags == MUTT_SAVE_OVERWRITE)
     return fopen (path, "w");		/* __FOPEN_CHECKED__ */
-  
+
   return safe_fopen (path, "w");
 }
 
@@ -735,14 +736,14 @@ int mutt_save_attachment (FILE *fp, BODY *m, const char *path, int flags, HEADER
 {
   if (fp)
   {
-    
+
     /* recv mode */
 
-    if(hdr &&
-	m->hdr &&
-	m->encoding != ENCBASE64 &&
-	m->encoding != ENCQUOTEDPRINTABLE &&
-	mutt_is_message_type(m->type, m->subtype))
+    if (hdr &&
+        m->hdr &&
+        m->encoding != ENCBASE64 &&
+        m->encoding != ENCQUOTEDPRINTABLE &&
+        mutt_is_message_type(m->type, m->subtype))
     {
       /* message type attachments are written to mail folders. */
 
@@ -752,7 +753,7 @@ int mutt_save_attachment (FILE *fp, BODY *m, const char *path, int flags, HEADER
       MESSAGE *msg;
       int chflags = 0;
       int r = -1;
-      
+
       hn = m->hdr;
       hn->msgno = hdr->msgno; /* required for MH/maildir */
       hn->read = 1;
@@ -770,7 +771,7 @@ int mutt_save_attachment (FILE *fp, BODY *m, const char *path, int flags, HEADER
       if (ctx.magic == MUTT_MBOX || ctx.magic == MUTT_MMDF)
 	chflags = CH_FROM | CH_UPDATE_LEN;
       chflags |= (ctx.magic == MUTT_MAILDIR ? CH_NOSTATUS : CH_UPDATE);
-      if (_mutt_copy_message (msg->fp, fp, hn, hn->content, 0, chflags) == 0 
+      if (_mutt_copy_message (msg->fp, fp, hn, hn->content, 0, chflags) == 0
 	  && mx_commit_message (msg, &ctx) == 0)
 	r = 0;
       else
@@ -783,9 +784,9 @@ int mutt_save_attachment (FILE *fp, BODY *m, const char *path, int flags, HEADER
     else
     {
       /* In recv mode, extract from folder and decode */
-      
+
       STATE s;
-      
+
       memset (&s, 0, sizeof (s));
       if ((s.fpout = mutt_save_attachment_open (path, flags)) == NULL)
       {
@@ -795,7 +796,7 @@ int mutt_save_attachment (FILE *fp, BODY *m, const char *path, int flags, HEADER
       }
       fseeko ((s.fpin = fp), m->offset, 0);
       mutt_decode_attachment (m, &s);
-      
+
       if (fclose (s.fpout) != 0)
       {
 	mutt_perror ("fclose");
@@ -815,7 +816,7 @@ int mutt_save_attachment (FILE *fp, BODY *m, const char *path, int flags, HEADER
       mutt_perror ("fopen");
       return (-1);
     }
-    
+
     if ((nfp = mutt_save_attachment_open (path, flags)) == NULL)
     {
       mutt_perror ("fopen");
@@ -884,7 +885,7 @@ int mutt_decode_save_attachment (FILE *fp, BODY *m, const char *path,
     saved_encoding = m->encoding;
     if (!is_multipart (m))
       m->encoding = ENC8BIT;
-    
+
     m->length = st.st_size;
     m->offset = 0;
     saved_parts = m->parts;
@@ -922,7 +923,7 @@ int mutt_decode_save_attachment (FILE *fp, BODY *m, const char *path,
 /* Ok, the difference between send and receive:
  * recv: BODY->filename is a suggested name, and Context|HEADER points
  *       to the attachment in mailbox which is encoded
- * send: BODY->filename points to the un-encoded file which contains the 
+ * send: BODY->filename points to the un-encoded file which contains the
  *       attachment
  */
 
@@ -938,17 +939,17 @@ int mutt_print_attachment (FILE *fp, BODY *a)
 
   snprintf (type, sizeof (type), "%s/%s", TYPE (a), a->subtype);
 
-  if (rfc1524_mailcap_lookup (a, type, NULL, MUTT_PRINT)) 
+  if (rfc1524_mailcap_lookup (a, type, NULL, MUTT_PRINT))
   {
     rfc1524_entry *entry;
     int piped = FALSE;
 
     dprint (2, (debugfile, "Using mailcap...\n"));
-    
+
     entry = rfc1524_new_entry ();
     rfc1524_mailcap_lookup (a, type, entry, MUTT_PRINT);
-    if (mutt_buffer_rfc1524_expand_filename (entry->nametemplate, a->filename,
-                                             newfile))
+    if (mutt_rfc1524_expand_filename (entry->nametemplate, a->filename,
+                                      newfile))
     {
       if (!fp)
       {
@@ -971,7 +972,7 @@ int mutt_print_attachment (FILE *fp, BODY *a)
       mutt_save_attachment (fp, a, mutt_b2s (newfile), 0, NULL);
 
     mutt_buffer_strcpy (command, entry->printcommand);
-    piped = mutt_buffer_rfc1524_expand_command (a, mutt_b2s (newfile), type, command);
+    piped = mutt_rfc1524_expand_command (a, mutt_b2s (newfile), type, command);
 
     mutt_endwin (NULL);
 
@@ -1030,10 +1031,10 @@ int mutt_print_attachment (FILE *fp, BODY *a)
     mutt_buffer_mktemp (newfile);
     if (mutt_decode_save_attachment (fp, a, mutt_b2s (newfile), MUTT_PRINTING, 0) == 0)
     {
-      
+
       dprint (2, (debugfile, "successfully decoded %s type attachment to %s\n",
 		  type, mutt_b2s (newfile)));
-      
+
       if ((ifp = fopen (mutt_b2s (newfile), "r")) == NULL)
       {
 	mutt_perror ("fopen");
@@ -1041,7 +1042,7 @@ int mutt_print_attachment (FILE *fp, BODY *a)
       }
 
       dprint (2, (debugfile, "successfully opened %s read-only\n", mutt_b2s (newfile)));
-      
+
       mutt_endwin (NULL);
       if ((thepid = mutt_create_filter (NONULL(PrintCmd), &fpout, NULL, NULL)) < 0)
       {
@@ -1050,7 +1051,7 @@ int mutt_print_attachment (FILE *fp, BODY *a)
       }
 
       dprint (2, (debugfile, "Filter created.\n"));
-      
+
       mutt_copy_stream (ifp, fpout);
 
       safe_fclose (&fpout);
