@@ -1,24 +1,24 @@
-/* 
+/*
  * Copyright (C) 2004 g10 Code GmbH
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation; either version 2 of the License, or
  *     (at your option) any later version.
- * 
+ *
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
- * 
+ *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-/* 
-    This is a crytpo module wrapping the classic pgp code.
- */
+/*
+  This is a crytpo module wrapping the classic pgp code.
+*/
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -107,31 +107,31 @@ static void crypt_mod_pgp_extract_keys_from_attachment_list (FILE *fp, int tag,
 }
 
 struct crypt_module_specs crypt_mod_pgp_classic =
-  { APPLICATION_PGP,
-    {
-      NULL,			/* init */
-      crypt_mod_pgp_void_passphrase,
-      crypt_mod_pgp_valid_passphrase,
-      crypt_mod_pgp_decrypt_mime,
-      crypt_mod_pgp_application_handler,
-      crypt_mod_pgp_encrypted_handler,
-      crypt_mod_pgp_findkeys,
-      crypt_mod_pgp_sign_message,
-      crypt_mod_pgp_verify_one,
-      crypt_mod_pgp_send_menu,
-      NULL,
+{ APPLICATION_PGP,
+  {
+    NULL,			/* init */
+    crypt_mod_pgp_void_passphrase,
+    crypt_mod_pgp_valid_passphrase,
+    crypt_mod_pgp_decrypt_mime,
+    crypt_mod_pgp_application_handler,
+    crypt_mod_pgp_encrypted_handler,
+    crypt_mod_pgp_findkeys,
+    crypt_mod_pgp_sign_message,
+    crypt_mod_pgp_verify_one,
+    crypt_mod_pgp_send_menu,
+    NULL, /* (set_sender) */
 
-      crypt_mod_pgp_encrypt_message,
-      crypt_mod_pgp_make_key_attachment,
-      crypt_mod_pgp_check_traditional,
-      crypt_mod_pgp_traditional_encryptsign,
-      crypt_mod_pgp_invoke_getkeys,
-      crypt_mod_pgp_invoke_import,
-      crypt_mod_pgp_extract_keys_from_attachment_list,
+    crypt_mod_pgp_encrypt_message,
+    crypt_mod_pgp_make_key_attachment,
+    crypt_mod_pgp_check_traditional,
+    crypt_mod_pgp_traditional_encryptsign,
+    crypt_mod_pgp_invoke_getkeys,
+    crypt_mod_pgp_invoke_import,
+    crypt_mod_pgp_extract_keys_from_attachment_list,
 
-      NULL,			/* smime_getkeys */
-      NULL,			/* smime_verify_sender */
-      NULL,			/* smime_build_smime_entity */
-      NULL,			/* smime_invoke_import */
-    }
-  };
+    NULL,			/* smime_getkeys */
+    NULL,			/* smime_verify_sender */
+    NULL,			/* smime_build_smime_entity */
+    NULL,			/* smime_invoke_import */
+  }
+};
