@@ -1,24 +1,24 @@
-/* 
+/*
  * Copyright (C) 2004 g10 Code GmbH
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation; either version 2 of the License, or
  *     (at your option) any later version.
- * 
+ *
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
- * 
+ *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-/* 
-    This is a crytpo module wrapping the gpgme based pgp code.
- */
+/*
+  This is a crytpo module wrapping the gpgme based pgp code.
+*/
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -95,12 +95,10 @@ static BODY *crypt_mod_pgp_encrypt_message (BODY *a, char *keylist, int sign)
   return pgp_gpgme_encrypt_message (a, keylist, sign);
 }
 
-#ifdef HAVE_GPGME_OP_EXPORT_KEYS
 static BODY *crypt_mod_pgp_make_key_attachment (char *tempf)
 {
   return pgp_gpgme_make_key_attachment (tempf);
 }
-#endif
 
 static void crypt_mod_pgp_set_sender (const char *sender)
 {
@@ -108,39 +106,35 @@ static void crypt_mod_pgp_set_sender (const char *sender)
 }
 
 struct crypt_module_specs crypt_mod_pgp_gpgme =
-  { APPLICATION_PGP,
-    {
-      /* Common.  */
-      crypt_mod_pgp_init,
-      crypt_mod_pgp_void_passphrase,
-      crypt_mod_pgp_valid_passphrase,
-      crypt_mod_pgp_decrypt_mime,
-      crypt_mod_pgp_application_handler,
-      crypt_mod_pgp_encrypted_handler,
-      crypt_mod_pgp_findkeys,
-      crypt_mod_pgp_sign_message,
-      crypt_mod_pgp_verify_one,
-      crypt_mod_pgp_send_menu,
-      crypt_mod_pgp_set_sender,
+{ APPLICATION_PGP,
+  {
+    /* Common.  */
+    crypt_mod_pgp_init,
+    crypt_mod_pgp_void_passphrase,
+    crypt_mod_pgp_valid_passphrase,
+    crypt_mod_pgp_decrypt_mime,
+    crypt_mod_pgp_application_handler,
+    crypt_mod_pgp_encrypted_handler,
+    crypt_mod_pgp_findkeys,
+    crypt_mod_pgp_sign_message,
+    crypt_mod_pgp_verify_one,
+    crypt_mod_pgp_send_menu,
+    crypt_mod_pgp_set_sender,
 
-      /* PGP specific.  */
-      crypt_mod_pgp_encrypt_message,
-#ifdef HAVE_GPGME_OP_EXPORT_KEYS
-      crypt_mod_pgp_make_key_attachment,
-#else
-      NULL,
-#endif
-      crypt_mod_pgp_check_traditional,
-      NULL, 			/* pgp_traditional_encryptsign  */
-      NULL, /* pgp_invoke_getkeys  */
-      crypt_mod_pgp_invoke_import,
-      NULL, /* pgp_extract_keys_from_attachment_list  */
+    /* PGP specific.  */
+    crypt_mod_pgp_encrypt_message,
+    crypt_mod_pgp_make_key_attachment,
+    crypt_mod_pgp_check_traditional,
+    NULL, 			/* pgp_traditional_encryptsign  */
+    NULL, /* pgp_invoke_getkeys  */
+    crypt_mod_pgp_invoke_import,
+    NULL, /* pgp_extract_keys_from_attachment_list  */
 
-      NULL,			/* smime_getkeys */
-      NULL,			/* smime_verify_sender */
-      NULL,			/* smime_build_smime_entity */
-      NULL,			/* smime_invoke_import */
-    }
-  };
+    NULL,			/* smime_getkeys */
+    NULL,			/* smime_verify_sender */
+    NULL,			/* smime_build_smime_entity */
+    NULL,			/* smime_invoke_import */
+  }
+};
 
 #endif
