@@ -1,20 +1,20 @@
 /*
  * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
- * 
+ *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation; either version 2 of the License, or
  *     (at your option) any later version.
- * 
+ *
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
- * 
+ *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */ 
+ */
 
 /* Close approximation of the mailx(1) builtin editor for sending mail. */
 
@@ -29,6 +29,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <locale.h>
 #include <ctype.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -86,7 +87,8 @@ be_snarf_data (FILE *f, char **buf, int *bufmax, int *buflen, LOFF_T offset,
       safe_realloc (&buf, sizeof (char *) * (*bufmax += 25));
     buf[(*buflen)++] = safe_strdup (tmp);
   }
-  if (buf && *bufmax == *buflen) { /* Do not smash memory past buf */
+  if (buf && *bufmax == *buflen)    /* Do not smash memory past buf */
+  {
     safe_realloc (&buf, sizeof (char *) * (++*bufmax));
   }
   if (buf) buf[*buflen] = NULL;
@@ -99,7 +101,7 @@ be_snarf_file (const char *path, char **buf, int *max, int *len, int verbose)
   FILE *f;
   char tmp[LONG_STRING];
   struct stat sb;
-  
+
   if ((f = fopen (path, "r")))
   {
     fstat (fileno (f), &sb);
@@ -123,7 +125,7 @@ static int be_barf_file (const char *path, char **buf, int buflen)
 {
   FILE *f;
   int i;
-  
+
   if ((f = fopen (path, "w")) == NULL)		/* __FOPEN_CHECKED__ */
   {
     addstr (strerror (errno));
@@ -160,7 +162,9 @@ be_include_messages (char *msg, char **buf, int *bufmax, int *buflen,
       /* add the attribution */
       if (Attribution)
       {
+        setlocale (LC_TIME, NONULL (AttributionLocale));
 	mutt_make_string (tmp, sizeof (tmp) - 1, Attribution, Context, Context->hdrs[n]);
+        setlocale (LC_TIME, "");
 	strcat (tmp, "\n");	/* __STRCAT_CHECKED__ */
       }
 
@@ -321,7 +325,7 @@ int mutt_builtin_editor (const char *path, HEADER *msg, HEADER *cur)
   int done = 0;
   int i;
   char *p;
-  
+
   scrollok (stdscr, TRUE);
 
   be_edit_header (msg->env, 0);
@@ -378,7 +382,7 @@ int mutt_builtin_editor (const char *path, HEADER *msg, HEADER *cur)
 	      /* include the current message */
 	      p = tmp + mutt_strlen (tmp) + 1;
 	      snprintf (tmp + mutt_strlen (tmp), sizeof (tmp) - mutt_strlen (tmp), " %d",
-								cur->msgno + 1);
+                        cur->msgno + 1);
 	    }
 	    buf = be_include_messages (p, buf, &bufmax, &buflen,
 				       (ascii_tolower (tmp[1]) == 'm'),
@@ -479,7 +483,7 @@ int mutt_builtin_editor (const char *path, HEADER *msg, HEADER *cur)
 	safe_realloc (&buf, sizeof (char *) * (bufmax += 25));
       buf[buflen++] = safe_strdup (tmp[1] == '~' ? tmp + 1 : tmp);
     }
-    
+
     tmp[0] = 0;
   }
 
