@@ -1,20 +1,20 @@
 /*
  * Copyright (C) 1996-2000,2009 Michael R. Elkins <me@mutt.org>
- * 
+ *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation; either version 2 of the License, or
  *     (at your option) any later version.
- * 
+ *
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
- * 
+ *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */ 
+ */
 
 #define HELP_C
 
@@ -41,7 +41,7 @@ static const struct binding_t *help_lookupFunction (int op, int menu)
     /* first look in the generic map for the function */
     for (i = 0; OpGeneric[i].name; i++)
       if (OpGeneric[i].op == op)
-	return (&OpGeneric[i]);    
+	return (&OpGeneric[i]);
   }
 
   if ((map = km_get_table(menu)))
@@ -50,7 +50,7 @@ static const struct binding_t *help_lookupFunction (int op, int menu)
       if (map[i].op == op)
 	return (&map[i]);
   }
-  
+
   return (NULL);
 }
 
@@ -71,7 +71,7 @@ mutt_compile_help (char *buf, size_t buflen, int menu, const struct mapping_t *i
   int i;
   size_t len;
   char *pbuf = buf;
-  
+
   for (i = 0; items[i].name && buflen > 2; i++)
   {
     if (i)
@@ -103,6 +103,8 @@ static int print_macro (FILE *f, int maxwidth, const char **macro)
   {
     if (k == (size_t)(-1) || k == (size_t)(-2))
     {
+      if (k == (size_t)(-1))
+        memset (&mbstate1, 0, sizeof (mbstate1));
       k = (k == (size_t)(-1)) ? 1 : len;
       wc = replacement_char ();
     }
@@ -165,6 +167,8 @@ static int get_wrapped_width (const char *t, size_t wid)
       m = n;
     if (k == (size_t)(-1) || k == (size_t)(-2))
     {
+      if (k == (size_t)(-1))
+        memset (&mbstate, 0, sizeof (mbstate));
       k = (k == (size_t)(-1)) ? 1 : len;
       wc = replacement_char ();
     }
@@ -205,7 +209,7 @@ static void format_line (FILE *f, int ismacro,
 
   /* don't try to press string into one line with less than 40 characters.
      The double parenthesis avoids a gcc warning, sigh ... */
-  if ((split = COLS < 40))
+  if ((split = MuttIndexWindow->cols < 40))
   {
     col_a = col = 0;
     col_b = LONG_STRING;
@@ -213,8 +217,8 @@ static void format_line (FILE *f, int ismacro,
   }
   else
   {
-    col_a = COLS > 83 ? (COLS - 32) >> 2 : 12;
-    col_b = COLS > 49 ? (COLS - 10) >> 1 : 19;
+    col_a = MuttIndexWindow->cols > 83 ? (MuttIndexWindow->cols - 32) >> 2 : 12;
+    col_b = MuttIndexWindow->cols > 49 ? (MuttIndexWindow->cols - 10) >> 1 : 19;
     col = pad (f, mutt_strwidth(t1), col_a);
   }
 
@@ -248,7 +252,7 @@ static void format_line (FILE *f, int ismacro,
   {
     while (*t3)
     {
-      n = COLS - col;
+      n = MuttIndexWindow->cols - col;
 
       if (ismacro >= 0)
       {
@@ -267,7 +271,7 @@ static void format_line (FILE *f, int ismacro,
 	}
 	else
 	{
-	  n += col - COLS;
+	  n += col - MuttIndexWindow->cols;
 	  if (option (OPTMARKERS))
 	    ++n;
 	}
@@ -303,7 +307,7 @@ static void dump_menu (FILE *f, int menu)
       {
 	b = help_lookupFunction (map->op, menu);
 	format_line (f, 0, buf, b ? b->name : "UNKNOWN",
-	      b ? _(HelpStrings[b->op]) : _("ERROR: please report this bug"));
+                     b ? _(HelpStrings[b->op]) : _("ERROR: please report this bug"));
       }
     }
   }
@@ -346,34 +350,35 @@ void mutt_help (int menu)
   desc = mutt_getnamebyvalue (menu, Menus);
   if (!desc)
     desc = _("<UNKNOWN>");
-  
-  do {
+
+  do
+  {
     if ((f = safe_fopen (t, "w")) == NULL)
     {
       mutt_perror (t);
       return;
     }
-  
+
     dump_menu (f, menu);
     if (menu != MENU_EDITOR && menu != MENU_PAGER)
     {
       fputs (_("\nGeneric bindings:\n\n"), f);
       dump_menu (f, MENU_GENERIC);
     }
-  
+
     fputs (_("\nUnbound functions:\n\n"), f);
     if (funcs)
       dump_unbound (f, funcs, Keymaps[menu], NULL);
     if (menu != MENU_PAGER)
       dump_unbound (f, OpGeneric, Keymaps[MENU_GENERIC], Keymaps[menu]);
-  
+
     safe_fclose (&f);
-  
+
     snprintf (buf, sizeof (buf), _("Help for %s"), desc);
   }
   while
     (mutt_do_pager (buf, t,
-		    M_PAGER_RETWINCH | M_PAGER_MARKER | M_PAGER_NSKIP | M_PAGER_NOWRAP,
+		    MUTT_PAGER_RETWINCH | MUTT_PAGER_MARKER | MUTT_PAGER_NSKIP | MUTT_PAGER_NOWRAP,
 		    NULL)
      == OP_REFORMAT_WINCH);
 }
