@@ -1,20 +1,20 @@
 /*
  * Copyright (C) 1996-2000,2002,2010-2011 Michael R. Elkins <me@mutt.org>
- * 
+ *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation; either version 2 of the License, or
  *     (at your option) any later version.
- * 
+ *
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
- * 
+ *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */ 
+ */
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -40,29 +40,29 @@
 #include "functions.h"
 
 const struct mapping_t Menus[] = {
- { "alias",	MENU_ALIAS },
- { "attach",	MENU_ATTACH },
- { "browser",	MENU_FOLDER },
- { "compose",	MENU_COMPOSE },
- { "editor",	MENU_EDITOR },
- { "index",	MENU_MAIN },
- { "pager",	MENU_PAGER },
- { "postpone",	MENU_POST },
- { "pgp",	MENU_PGP },
- { "smime",	MENU_SMIME },
+  { "alias",	MENU_ALIAS },
+  { "attach",	MENU_ATTACH },
+  { "browser",	MENU_FOLDER },
+  { "compose",	MENU_COMPOSE },
+  { "editor",	MENU_EDITOR },
+  { "index",	MENU_MAIN },
+  { "pager",	MENU_PAGER },
+  { "postpone",	MENU_POST },
+  { "pgp",	MENU_PGP },
+  { "smime",	MENU_SMIME },
 #ifdef CRYPT_BACKEND_GPGME
- { "key_select_pgp",	MENU_KEY_SELECT_PGP },
- { "key_select_smime",	MENU_KEY_SELECT_SMIME },
+  { "key_select_pgp",	MENU_KEY_SELECT_PGP },
+  { "key_select_smime",	MENU_KEY_SELECT_SMIME },
 #endif
 
 #ifdef MIXMASTER
   { "mix", 	MENU_MIX },
 #endif
-  
 
- { "query",	MENU_QUERY },
- { "generic",	MENU_GENERIC },
- { NULL,	0 }
+
+  { "query",	MENU_QUERY },
+  { "generic",	MENU_GENERIC },
+  { NULL,	0 }
 };
 
 #define mutt_check_menu(s) mutt_getvaluebyname(s, Menus)
@@ -91,7 +91,7 @@ static struct mapping_t KeyNames[] = {
 #endif
 #ifdef KEY_NEXT
   { "<Next>",    KEY_NEXT },
-#endif  
+#endif
 #ifdef NCURSES_VERSION
   /* extensions supported by ncurses.  values are filled in during initialization */
 
@@ -149,16 +149,16 @@ static int parse_fkey(char *s)
   char *t;
   int n = 0;
 
-  if(s[0] != '<' || ascii_tolower(s[1]) != 'f')
+  if (s[0] != '<' || ascii_tolower(s[1]) != 'f')
     return -1;
 
-  for(t = s + 2; *t && isdigit((unsigned char) *t); t++)
+  for (t = s + 2; *t && isdigit((unsigned char) *t); t++)
   {
     n *= 10;
     n += *t - '0';
   }
 
-  if(*t != '>')
+  if (*t != '>')
     return -1;
   else
     return n;
@@ -176,7 +176,8 @@ static int parse_keycode (const char *s)
   while (ISSPACE(*endChar))
     ++endChar;
   /* negative keycodes don't make sense, also detect overflow */
-  if (*endChar != '>' || result < 0 || result == LONG_MAX) {
+  if (*endChar != '>' || result < 0 || result == LONG_MAX)
+  {
     return -1;
   }
 
@@ -192,14 +193,14 @@ static int parsekeys (const char *str, keycode_t *d, int max)
 
   strfcpy(buff, str, sizeof(buff));
   s = buff;
-  
+
   while (*s && len)
   {
     *d = '\0';
-    if(*s == '<' && (t = strchr(s, '>')))
+    if (*s == '<' && (t = strchr(s, '>')))
     {
       t++; c = *t; *t = '\0';
-      
+
       if ((n = mutt_getvaluebyname (s, KeyNames)) != -1)
       {
 	s = t;
@@ -215,11 +216,11 @@ static int parsekeys (const char *str, keycode_t *d, int max)
 	s = t;
 	*d = n;
       }
-      
+
       *t = c;
     }
 
-    if(!*d)
+    if (!*d)
     {
       *d = (unsigned char)*s;
       s++;
@@ -307,7 +308,7 @@ static int get_op (const struct binding_t *bindings, const char *start, size_t l
 
   for (i = 0; bindings[i].name; i++)
   {
-    if (!ascii_strncasecmp (start, bindings[i].name, len) &&   
+    if (!ascii_strncasecmp (start, bindings[i].name, len) &&
 	mutt_strlen (bindings[i].name) == len)
       return bindings[i].op;
   }
@@ -497,7 +498,7 @@ int km_dokey (int menu)
       if (menu != MENU_EDITOR && menu != MENU_PAGER)
       {
 	/* check generic menu */
-	bindings = OpGeneric; 
+	bindings = OpGeneric;
 	if ((func = get_func (bindings, tmp.op)))
 	  return tmp.op;
       }
@@ -753,15 +754,15 @@ void km_init (void)
 
 #ifdef MIXMASTER
   create_bindings (OpMix, MENU_MIX);
-  
+
   km_bindkey ("<space>", MENU_MIX, OP_GENERIC_SELECT_ENTRY);
   km_bindkey ("h", MENU_MIX, OP_MIX_CHAIN_PREV);
   km_bindkey ("l", MENU_MIX, OP_MIX_CHAIN_NEXT);
 #endif
-  
+
   /* bindings for the line editor */
   create_bindings (OpEditor, MENU_EDITOR);
-  
+
   km_bindkey ("<up>", MENU_EDITOR, OP_EDITOR_HISTORY_UP);
   km_bindkey ("<down>", MENU_EDITOR, OP_EDITOR_HISTORY_DOWN);
   km_bindkey ("<left>", MENU_EDITOR, OP_EDITOR_BACKWARD_CHAR);
@@ -771,10 +772,10 @@ void km_init (void)
   km_bindkey ("<backspace>", MENU_EDITOR, OP_EDITOR_BACKSPACE);
   km_bindkey ("<delete>", MENU_EDITOR, OP_EDITOR_BACKSPACE);
   km_bindkey ("\177", MENU_EDITOR, OP_EDITOR_BACKSPACE);
-  
+
   /* generic menu keymap */
   create_bindings (OpGeneric, MENU_GENERIC);
-  
+
   km_bindkey ("<home>", MENU_GENERIC, OP_FIRST_ENTRY);
   km_bindkey ("<end>", MENU_GENERIC, OP_LAST_ENTRY);
   km_bindkey ("<pagedown>", MENU_GENERIC, OP_NEXT_PAGE);
@@ -796,7 +797,7 @@ void km_init (void)
   km_bindkey ("<enter>", MENU_GENERIC, OP_GENERIC_SELECT_ENTRY);
 
   /* Miscellaneous extra bindings */
-  
+
   km_bindkey (" ", MENU_MAIN, OP_DISPLAY_MESSAGE);
   km_bindkey ("<up>", MENU_MAIN, OP_MAIN_PREV_UNDELETED);
   km_bindkey ("<down>", MENU_MAIN, OP_MAIN_NEXT_UNDELETED);
@@ -828,7 +829,7 @@ void km_init (void)
   km_bindkey ("9", MENU_PAGER, OP_JUMP);
 
   km_bindkey ("<enter>", MENU_PAGER, OP_NEXT_LINE);
-  
+
   km_bindkey ("<return>", MENU_ALIAS, OP_GENERIC_SELECT_ENTRY);
   km_bindkey ("<enter>",  MENU_ALIAS, OP_GENERIC_SELECT_ENTRY);
   km_bindkey ("<space>", MENU_ALIAS, OP_TAG);
@@ -933,8 +934,8 @@ static char *parse_keymap (int *menu, BUFFER *s, int maxmenus, int *nummenus, BU
 
       if ((menu[i] = mutt_check_menu (p)) == -1)
       {
-         snprintf (err->data, err->dsize, _("%s: no such menu"), p);
-         goto error;
+        snprintf (err->data, err->dsize, _("%s: no such menu"), p);
+        goto error;
       }
       ++i;
       if (q)
@@ -966,7 +967,7 @@ static int
 try_bind (char *key, int menu, char *func, const struct binding_t *bindings)
 {
   int i;
-  
+
   for (i = 0; bindings[i].name; i++)
     if (mutt_strcmp (func, bindings[i].name) == 0)
     {
@@ -1051,7 +1052,7 @@ int mutt_parse_bind (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
     {
       /* First check the "generic" list of commands */
       if (menu[i] == MENU_PAGER || menu[i] == MENU_EDITOR ||
-      menu[i] == MENU_GENERIC ||
+          menu[i] == MENU_GENERIC ||
 	  try_bind (key, menu[i], buf->data, OpGeneric) != 0)
       {
         /* Now check the menu-specific list of commands (if they exist) */
@@ -1122,7 +1123,7 @@ int mutt_parse_macro (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 /* exec function-name */
 int mutt_parse_exec (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 {
-  int ops[128]; 
+  int ops[128];
   int nops = 0;
   const struct binding_t *bindings = NULL;
   char *function;
@@ -1138,7 +1139,7 @@ int mutt_parse_exec (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
     mutt_extract_token (buf, s, 0);
     function = buf->data;
 
-    if ((bindings = km_get_table (CurrentMenu)) == NULL 
+    if ((bindings = km_get_table (CurrentMenu)) == NULL
 	&& CurrentMenu != MENU_PAGER)
       bindings = OpGeneric;
 
@@ -1154,9 +1155,9 @@ int mutt_parse_exec (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
     }
     nops++;
   }
-  while(MoreArgs(s) && nops < sizeof(ops)/sizeof(ops[0]));
+  while (MoreArgs(s) && nops < sizeof(ops)/sizeof(ops[0]));
 
-  while(nops)
+  while (nops)
     mutt_push_macro_event (0, ops[--nops]);
 
   return 0;
@@ -1171,12 +1172,13 @@ void mutt_what_key (void)
   int ch;
 
   mutt_window_mvprintw (MuttMessageWindow, 0, 0, _("Enter keys (^G to abort): "));
-  do {
+  do
+  {
     ch = getch();
     if (ch != ERR && ch != ctrl ('G'))
     {
       mutt_message(_("Char = %s, Octal = %o, Decimal = %d"),
-	       km_keyname(ch), ch, ch);
+                   km_keyname(ch), ch, ch);
     }
   }
   while (ch != ERR && ch != ctrl ('G'));
